@@ -3,8 +3,8 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright: (C) 2005-2006 Munteanu Alexandru
- * Contact: io_alex_2002@yahoo.fr
+ * Copyright: (C) 2005-2009 Alexandru Munteanu
+ * Contact: io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
  *
@@ -41,7 +41,7 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #else
-#define VERSION "0.3.1"
+#define VERSION "0.5.4"
 #define PACKAGE_NAME "mp3splt-gtk"
 #endif
 
@@ -53,7 +53,7 @@
 #include "main_win.h"
 #include "mp3splt-gtk.h"
 #include "tree_tab.h"
-#include "splitted_files.h"
+#include "split_files.h"
 #include "cddb_cue.h"
 #include "utilities.h"
 #include "preferences_tab.h"
@@ -61,6 +61,7 @@
 #include "special_split.h"
 #include "utilities.h"
 #include "player_tab.h"
+#include "player.h"
 
 //main window
 GtkWidget *window;
@@ -103,38 +104,59 @@ extern GArray *splitpoints;
 extern gint save_dialog;
 extern gint selected_id;
 extern splt_state *the_state;
-extern freedb_results *search_results;
+extern splt_freedb_results *search_results;
 extern GList *player_pref_list;
-extern gchar **splitted_files;
-extern gint max_splitted_files;
+extern gchar **split_files;
+extern gint max_split_files;
 extern gint no_top_connect_action;
+extern gint selected_player;
+extern GtkWidget *connect_button;
+extern silence_wave *silence_points;
+extern gint number_of_silence_points;
+
+GtkWidget *playlist_box;
 
 //close the window and exit button function
-void quit( GtkWidget *widget,
-	   gpointer   data )
+void quit(GtkWidget *widget, gpointer   data)
 {
   //if we are in the middle of the split
   if (we_are_splitting)
-    {
-      libmp3splt_stop_split();
-      //wait to finish split then quit
-      we_quit_main_program = TRUE;
-      put_status_message(_(" info: stopping the split process"
-			   " before exiting"));
-    }
-  else
-    //quit program
-    {
-      //free player choices list
-      g_list_free(player_pref_list);
-      //we free the splitpoints
-      g_array_free(splitpoints, TRUE);
-      //we free left variables in the library
-      libmp3splt_free_left_variables(the_state);
-      
-      //we definetly quit the program...
-      gtk_main_quit ();
-    }
+  {
+    gint err = SPLT_OK;
+    mp3splt_stop_split(the_state,&err);
+    print_status_bar_confirmation(err);
+
+    //wait to finish split then quit
+    we_quit_main_program = TRUE;
+    put_status_message(_(" info: stopping the split process before exiting"));
+  }
+
+  //quit the player : currently closes gstreamer
+  if (player_is_running())
+  {
+    player_quit();
+  }
+
+  //free player choices list
+  g_list_free(player_pref_list);
+  //we free the splitpoints
+  g_array_free(splitpoints, TRUE);
+
+  //we free the GUI silence points
+  if (silence_points)
+  {
+    g_free(silence_points);
+    silence_points = NULL;
+    number_of_silence_points = 0;
+  }
+
+  gint err = SPLT_OK;
+  //we free left variables in the library
+  mp3splt_free_state(the_state,&err);
+  print_status_bar_confirmation(err);
+
+  //we definetly quit the program...
+  gtk_main_quit ();
 }
 
 //initializes window
@@ -150,10 +172,10 @@ GtkWidget *initialize_window()
   //sets the width
   gtk_container_set_border_width (GTK_CONTAINER (window), 0);
   g_signal_connect (G_OBJECT (window), "delete_event",
-		    G_CALLBACK (quit), NULL);
+                    G_CALLBACK (quit), NULL);
   
   gtk_window_set_position (GTK_WINDOW(window),
-			   GTK_WIN_POS_CENTER);
+                           GTK_WIN_POS_CENTER);
   
   //for the bitmap
   GdkPixbuf *pixbuf;
@@ -166,7 +188,7 @@ GtkWidget *initialize_window()
 
 //about window
 void about_window(GtkWidget *widget,
-		  gpointer *data)
+                  gpointer *data)
 {
   GtkWidget *dialog;
   
@@ -176,55 +198,59 @@ void about_window(GtkWidget *widget,
   GdkPixbuf *pixbuf;
   pixbuf = gdk_pixbuf_new_from_file (PIXMAP_PATH"mp3splt-gtk.png", NULL);
   gtk_about_dialog_set_logo(GTK_ABOUT_DIALOG(dialog), 
-			    pixbuf);
+                            pixbuf);
   
   gtk_about_dialog_set_name(GTK_ABOUT_DIALOG(dialog), 
-			    (gchar *)PACKAGE_NAME);
+                            (gchar *)PACKAGE_NAME);
   gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(dialog), 
-			       VERSION);
+                               VERSION);
   gtk_about_dialog_set_copyright(GTK_ABOUT_DIALOG(dialog),
-				 PACKAGE_NAME" (c) 2005-2006 Munteanu"
-				 " Alexandru \n mp3splt (c) 2002-2005 Matteo Trotta");
+                                 PACKAGE_NAME" (c) 2005-2009 Munteanu"
+                                 " Alexandru \n mp3splt (c) 2002-2005 Matteo Trotta");
   
   gchar *b1,*b2;
   gchar b3[100];
   b1 = (gchar *)_("using");
   b2 = (gchar *)_("created from");
-  g_snprintf(b3, 100, "-release of 27/02/06-\n%s libmp3splt 0.3.1 (%s mp3splt)", b1,b2);
+  gchar library_version[20];
+  mp3splt_get_version(library_version);
+  g_snprintf(b3, 100, "-release of 18/01/09-\n%s libmp3splt %s (%s mp3splt)",
+             b1, library_version, b2);
   
   gtk_about_dialog_set_comments (GTK_ABOUT_DIALOG(dialog), b3);
   
   gtk_about_dialog_set_license (GTK_ABOUT_DIALOG(dialog),
-				"\n"
-				"This program is free software; you can "
-				"redistribute it and/or \n"
-				"modify it under the terms of the GNU General Public License\n"
-				"as published by the Free Software "
-				"Foundation; either version 2\n"
-				"of the License, or (at your option) "
-				"any later version.\n\n"
-				"This program is distributed in the "
-				"hope that it will be useful,\n"
-				"but WITHOUT ANY WARRANTY; without even"
-				"the implied warranty of\n"
-				"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
-				"GNU General Public License for more details.\n\n"
-				"You should have received a copy of the GNU General Public License\n"
-				"along with this program; if not, write "
-				"to the Free Software\n"
-				"Foundation, Inc., 59 Temple Place -"
-				"Suite 330, Boston, MA  02111-1307, "
-				"USA.");
+                                "\n"
+                                "This program is free software; you can "
+                                "redistribute it and/or \n"
+                                "modify it under the terms of the GNU General Public License\n"
+                                "as published by the Free Software "
+                                "Foundation; either version 2\n"
+                                "of the License, or (at your option) "
+                                "any later version.\n\n"
+                                "This program is distributed in the "
+                                "hope that it will be useful,\n"
+                                "but WITHOUT ANY WARRANTY; without even"
+                                "the implied warranty of\n"
+                                "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+                                "GNU General Public License for more details.\n\n"
+                                "You should have received a copy of the GNU General Public License\n"
+                                "along with this program; if not, write "
+                                "to the Free Software\n"
+                                "Foundation, Inc., 59 Temple Place -"
+                                "Suite 330, Boston, MA  02111-1307, "
+                                "USA.");
 
   gtk_about_dialog_set_website (GTK_ABOUT_DIALOG(dialog),
-				"http://mp3splt.sourceforge.net/");
+                                "http://mp3splt.sourceforge.net/");
 
-  gtk_widget_show(dialog);
+  gtk_dialog_run(GTK_DIALOG(dialog));
+  gtk_widget_destroy(dialog);
 }
 
 //resizes the window event
 void resize_window_event(GtkWidget *toolbar_button,
-				 gpointer data)
+                                 gpointer data)
 {
   gtk_window_resize(GTK_WINDOW(window), WINDOW_X, WINDOW_Y);
 }
@@ -235,7 +261,7 @@ void remove_status_message()
 {
   guint status_id = 
     gtk_statusbar_get_context_id(GTK_STATUSBAR(status_bar),
-				 "mess");
+                                 "mess");
   gtk_statusbar_pop(GTK_STATUSBAR(status_bar), status_id);
 }
 
@@ -244,75 +270,89 @@ void put_status_message(gchar *text)
 {
   guint status_id = 
     gtk_statusbar_get_context_id(GTK_STATUSBAR(status_bar),
-				 "mess");
+                                 "mess");
   //remove old message
   gtk_statusbar_pop(GTK_STATUSBAR(status_bar), status_id);
   gtk_statusbar_push(GTK_STATUSBAR(status_bar), 
-		     status_id, text);
+                     status_id, text);
 }
 
 //event for the split button
-void cancel_button_event (GtkWidget *widget,
-			  gpointer data)
+void cancel_button_event(GtkWidget *widget, gpointer data)
 {
-  libmp3splt_stop_split();
+  gint err = SPLT_OK;
+  mp3splt_stop_split(the_state,&err);
+  print_status_bar_confirmation(err);
+  
   gtk_widget_set_sensitive(widget, FALSE);
   put_status_message(_(" info: stopping the split process.. please wait"));
 }
 
 //event for the split button
 void split_button_event (GtkWidget *widget,
-			 gpointer data)
+                         gpointer data)
 {
   //if we are not splitting
   if (!we_are_splitting)
     {
       //set the options
-      the_state->options.option_mins_secs = FALSE;
+      mp3splt_set_int_option(the_state, SPLT_OPT_OUTPUT_FILENAMES,
+                             SPLT_OUTPUT_DEFAULT);
+
+      gint err = SPLT_OK;
+
       //put the options from the preferences
       put_options_from_preferences();
-      
+
+      //set the output format for almost all the types of split
+      if (mp3splt_get_int_option(the_state, SPLT_OPT_SPLIT_MODE,&err)
+          != SPLT_OPTION_NORMAL_MODE)
+      {
+        if (!get_checked_output_radio_box())
+        {
+          mp3splt_set_int_option(the_state, SPLT_OPT_OUTPUT_FILENAMES,
+              SPLT_OUTPUT_FORMAT);
+        }
+      }
+ 
       //we put the starting status message
-      switch (the_state->options.split_mode)
-	{
-	case MP3SPLT_OPTION_NORMAL_MODE:
-	  put_status_message((gchar *)_(" info: starting normal split... "));
-	  break;
-	case MP3SPLT_OPTION_WRAP_MODE:
-	  put_status_message((gchar *)_(" info: starting wrap mode split... "));
-	  break;
-	case MP3SPLT_OPTION_TIME_MODE:
-	  put_status_message((gchar *)_(" info: starting time mode split... "));
-	  break;
-	case MP3SPLT_OPTION_SILENCE_MODE:
-	  put_status_message((gchar *)_(" info: starting silence mode split... "));
-	  break; 
-	case MP3SPLT_OPTION_MP3_ERROR_MODE:
-	  put_status_message((gchar *)_(" info: starting"
-					" error mode split... "));
-	  break;
-	default:
-	  break;
-	}
+      switch (mp3splt_get_int_option(the_state, SPLT_OPT_SPLIT_MODE, &err))
+        {
+        case SPLT_OPTION_NORMAL_MODE:
+          put_status_message((gchar *)_(" info: starting normal split... "));
+          break;
+        case SPLT_OPTION_WRAP_MODE:
+          put_status_message((gchar *)_(" info: starting wrap mode split... "));
+          break;
+        case SPLT_OPTION_TIME_MODE:
+          put_status_message((gchar *)_(" info: starting time mode split... "));
+          break;
+        case SPLT_OPTION_ERROR_MODE:
+          put_status_message((gchar *)_(" info: starting"
+                                        " error mode split... "));
+          break;
+        default:
+          break;
+        }
       
       filename_to_split = (gchar *)
-	gtk_entry_get_text(GTK_ENTRY(entry));
+        gtk_entry_get_text(GTK_ENTRY(entry));
       
       filename_path_of_split = (gchar *)
-	gtk_entry_get_text(GTK_ENTRY(directory_entry));
+        gtk_entry_get_text(GTK_ENTRY(directory_entry));
       
       if (filename_path_of_split != NULL)
-	{
-	  we_are_splitting = TRUE;
-	  g_thread_create((GThreadFunc)split_it,
-			  NULL, TRUE, NULL);
-	  gtk_widget_set_sensitive(GTK_WIDGET(cancel_button),
-				   TRUE);
-	}
+        {
+          we_are_splitting = TRUE;
+          g_thread_create((GThreadFunc)split_it,
+                          NULL, TRUE, NULL);
+          gtk_widget_set_sensitive(GTK_WIDGET(cancel_button),
+                                   TRUE);
+        }
       else
-	{
-	  put_status_message((gchar *)_(" error: no file selected "));
-	}
+        {
+          put_status_message((gchar *)_(" error: no file selected "));
+        }
     }
   else
     {
@@ -322,7 +362,7 @@ void split_button_event (GtkWidget *widget,
 
 //toolbar connect button event
 void toolbar_connect_button_event (GtkWidget *widget,
-				   gpointer data)
+                                   gpointer data)
 {
   if (!no_top_connect_action)
     {
@@ -330,24 +370,24 @@ void toolbar_connect_button_event (GtkWidget *widget,
       
       //when we push connect
       if (gtk_toggle_tool_button_get_active(GTK_TOGGLE_TOOL_BUTTON(widget)))
-	{
-	  connect_button_event(NULL,NULL);
-	  gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(widget),
-				    GTK_TOOLTIPS(the_tooltip), 
-				    (gchar *)_("disconnect from player"),"");
-	  gtk_tool_button_set_stock_id(GTK_TOOL_BUTTON(widget),
-				       GTK_STOCK_DISCONNECT);
-	}
+        {
+          connect_button_event(NULL,NULL);
+          gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(widget),
+                                    GTK_TOOLTIPS(the_tooltip), 
+                                    (gchar *)_("disconnect from player"),"");
+          gtk_tool_button_set_stock_id(GTK_TOOL_BUTTON(widget),
+                                       GTK_STOCK_DISCONNECT);
+        }
       else
-	//when we push disconnect
-	{
-	  disconnect_button_event(NULL,NULL);
-	  gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(widget),
-				    GTK_TOOLTIPS(the_tooltip), 
-				    (gchar *)_("connect to player"),"");
-	  gtk_tool_button_set_stock_id(GTK_TOOL_BUTTON(widget),
-				       GTK_STOCK_CONNECT);
-	}
+        //when we push disconnect
+        {
+          disconnect_button_event(NULL,NULL);
+          gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(widget),
+                                    GTK_TOOLTIPS(the_tooltip), 
+                                    (gchar *)_("connect to player"),"");
+          gtk_tool_button_set_stock_id(GTK_TOOL_BUTTON(widget),
+                                       GTK_STOCK_CONNECT);
+        }
     }
 }
 
@@ -370,71 +410,69 @@ GtkWidget *create_toolbar()
   toolbar_button = (GtkWidget *)
     gtk_tool_button_new_from_stock(GTK_STOCK_ZOOM_FIT);
   gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(toolbar_button),
-			    GTK_TOOLTIPS(tooltip), (gchar *)_("set"
-							      " window default size"),"");
+                            GTK_TOOLTIPS(tooltip), (gchar *)_("set"
+                                                              " window default size"),"");
   g_signal_connect(G_OBJECT(toolbar_button), "clicked",
-		   G_CALLBACK(resize_window_event), tooltip);
+                   G_CALLBACK(resize_window_event), tooltip);
   gtk_toolbar_insert(GTK_TOOLBAR(toolbar),
-		     GTK_TOOL_ITEM(toolbar_button), 0);
+                     GTK_TOOL_ITEM(toolbar_button), 0);
   
   //separator
   toolbar_button = (GtkWidget *)gtk_separator_tool_item_new();
   gtk_toolbar_insert(GTK_TOOLBAR(toolbar),
-		     GTK_TOOL_ITEM(toolbar_button), 1);
+                     GTK_TOOL_ITEM(toolbar_button), 1);
   gtk_tool_item_set_expand(GTK_TOOL_ITEM(toolbar_button),
-			   TRUE);
+                           TRUE);
   gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(toolbar_button),
-				   FALSE);
+                                   FALSE);
   
   //connect to player button
   toolbar_connect_button = (GtkWidget *)
     gtk_toggle_tool_button_new_from_stock(GTK_STOCK_CONNECT);
   gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(toolbar_connect_button),
-			    GTK_TOOLTIPS(tooltip), 
-			    (gchar *)_("connect to player"),"");
+                            GTK_TOOLTIPS(tooltip), 
+                            (gchar *)_("connect to player"),"");
   gtk_toolbar_insert(GTK_TOOLBAR(toolbar),
-		     GTK_TOOL_ITEM(toolbar_connect_button), 2);
+                     GTK_TOOL_ITEM(toolbar_connect_button), 2);
   g_signal_connect(G_OBJECT(toolbar_connect_button), "clicked",
-		   G_CALLBACK(toolbar_connect_button_event), 
-		   tooltip);
+                   G_CALLBACK(toolbar_connect_button_event), 
+                   tooltip);
   
   //separator
   toolbar_button = (GtkWidget *)gtk_separator_tool_item_new();
   gtk_toolbar_insert(GTK_TOOLBAR(toolbar),
-		     GTK_TOOL_ITEM(toolbar_button), 3);
+                     GTK_TOOL_ITEM(toolbar_button), 3);
   gtk_tool_item_set_expand(GTK_TOOL_ITEM(toolbar_button),
-			   TRUE);
+                           TRUE);
   gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(toolbar_button),
-				   FALSE);
+                                   FALSE);
 
   //split button
   split_button = (GtkWidget *)
     gtk_tool_button_new_from_stock(GTK_STOCK_APPLY);
   gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(split_button),
-			    GTK_TOOLTIPS(tooltip), (gchar *)_("split !"),"");
+                            GTK_TOOLTIPS(tooltip), (gchar *)_("split !"),"");
   gtk_toolbar_insert(GTK_TOOLBAR(toolbar),
-		     GTK_TOOL_ITEM(split_button), 4);
+                     GTK_TOOL_ITEM(split_button), 4);
   g_signal_connect(G_OBJECT(split_button), "clicked",
-		   G_CALLBACK(split_button_event), tooltip);
+                   G_CALLBACK(split_button_event), tooltip);
   
   //separator
   toolbar_button = (GtkWidget *)gtk_separator_tool_item_new();
   gtk_toolbar_insert(GTK_TOOLBAR(toolbar),
-		     GTK_TOOL_ITEM(toolbar_button), 5);
+                     GTK_TOOL_ITEM(toolbar_button), 5);
   gtk_tool_item_set_expand(GTK_TOOL_ITEM(toolbar_button),
-			   TRUE);
+                           TRUE);
   gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(toolbar_button),
-				   FALSE);
+                                   FALSE);
 
   //quit button
-  toolbar_button = (GtkWidget *)
-    gtk_tool_button_new_from_stock(GTK_STOCK_QUIT);
+  toolbar_button = (GtkWidget *) gtk_tool_button_new_from_stock(GTK_STOCK_QUIT);
   gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(toolbar_button),
-			    GTK_TOOLTIPS(tooltip), (gchar *)_("really wanna quit ?"),"");
+                            GTK_TOOLTIPS(tooltip), (gchar *)_("really wanna quit ?"),"");
   gtk_toolbar_insert(GTK_TOOLBAR(toolbar),
-		     GTK_TOOL_ITEM(toolbar_button), 6);
-  g_signal_connect(G_OBJECT(toolbar_button), "clicked",
-		   G_CALLBACK(quit), tooltip);
+                     GTK_TOOL_ITEM(toolbar_button), 6);
+  g_signal_connect(G_OBJECT(toolbar_button), "clicked", G_CALLBACK(quit), tooltip);
   
   //toolbar preferences
   gtk_toolbar_set_show_arrow(GTK_TOOLBAR(toolbar), TRUE);
@@ -495,14 +533,14 @@ GtkWidget *create_menu_bar()
   gtk_ui_manager_insert_action_group (ui, actions, 0);
   //set the actions to the window
   gtk_window_add_accel_group (GTK_WINDOW (window), 
-			      gtk_ui_manager_get_accel_group (ui));
+                              gtk_ui_manager_get_accel_group (ui));
   //add ui from string
   gtk_ui_manager_add_ui_from_string (ui, ui_info, -1, NULL);
   
   //attach the menu
   gtk_box_pack_start (GTK_BOX (menu_box), 
-		      gtk_ui_manager_get_widget(ui, "/MenuBar"),
-		      FALSE, FALSE, 0);
+                      gtk_ui_manager_get_widget(ui, "/MenuBar"),
+                      FALSE, FALSE, 0);
   
   //our toolbar
   GtkWidget *toolbar;
@@ -510,7 +548,7 @@ GtkWidget *create_menu_bar()
   
   //attach the toolbar
   gtk_box_pack_start (GTK_BOX (menu_box), toolbar,
-		      TRUE, TRUE, 0);
+                      TRUE, TRUE, 0);
   
   return menu_box;
 }
@@ -518,8 +556,8 @@ GtkWidget *create_menu_bar()
 //creates a cool button with image from stock
 //toggle_or_not = TRUE means we create a toggle button
 GtkWidget *create_cool_button( gchar *stock_id,
-			       gchar *label_text,
-			       gint toggle_or_not)
+                               gchar *label_text,
+                               gint toggle_or_not)
 {
   GtkWidget *box;
   GtkWidget *label;
@@ -554,18 +592,18 @@ GtkWidget *create_cool_button( gchar *stock_id,
 
 //when changing the page of the main notebook
 void notebook_page_changed_event(GtkNotebook *notebook,
-				 GtkNotebookPage *page,
-				 guint page_num,
-				 gpointer user_data)
+                                 GtkNotebookPage *page,
+                                 guint page_num,
+                                 gpointer user_data)
 {
   GtkWidget *tab_label;
   GtkWidget *current_page;
 
   current_page = gtk_notebook_get_nth_page(notebook,
-					   page_num);
+                                           page_num);
   tab_label = 
     (GtkWidget *)gtk_notebook_get_tab_label(notebook,
-					    GTK_WIDGET(current_page));
+                                            GTK_WIDGET(current_page));
   
   GString *pref;
   pref = g_string_new((gchar *)_("Preferences"));
@@ -578,17 +616,17 @@ void notebook_page_changed_event(GtkNotebook *notebook,
     {
       //if we are on the preferences tab
       if (preferences_tab)
-	{
-	  //if we have save dialog enabled in the preferences
-	  if(save_dialog)
-	    {
-	      if (check_if_different_from_config_file())
-		{
-		  popup_save_preferences_dialog(notebook, 
-						page_num);
-		}
-	    }
-	}
+        {
+          //if we have save dialog enabled in the preferences
+          if(save_dialog)
+            {
+              if (check_if_different_from_config_file())
+                {
+                  popup_save_preferences_dialog(notebook, 
+                                                page_num);
+                }
+            }
+        }
       preferences_tab = FALSE;
     }
   else
@@ -624,6 +662,9 @@ GtkWidget *create_main_vbox()
   main_vbox = gtk_vbox_new (FALSE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (main_vbox), 0);
 
+  frame = (GtkWidget *)create_choose_file_frame();
+  gtk_box_pack_start(GTK_BOX(main_vbox), frame, FALSE, FALSE, 0);
+
   /* tabbed notebook */
   notebook = gtk_notebook_new();
   gtk_box_pack_start (GTK_BOX (main_vbox), notebook, TRUE, TRUE, 0);
@@ -633,8 +674,8 @@ GtkWidget *create_main_vbox()
   gtk_notebook_set_scrollable(GTK_NOTEBOOK(notebook), TRUE);
   //event when changing the notebook page
   g_signal_connect (G_OBJECT (notebook), "switch-page",
-		    G_CALLBACK (notebook_page_changed_event), 
-		    NULL);
+                    G_CALLBACK (notebook_page_changed_event), 
+                    NULL);
   
   //creating the tree view
   GtkWidget *splitpoints_vbox;
@@ -651,32 +692,34 @@ GtkWidget *create_main_vbox()
       
   //player control frame
   player_box = (GtkWidget *)create_player_control_frame(tree_view);
-  gtk_box_pack_start (GTK_BOX (player_vbox), player_box, FALSE, FALSE, 0);
-  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), 
-			   player_vbox,
-			   (GtkWidget *)notebook_label);
-      
-  frame = (GtkWidget *)create_choose_file_frame();
-  gtk_box_pack_start (GTK_BOX (player_vbox), frame, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX(player_vbox), player_box, FALSE, FALSE, 0);
 
+  //playlist control frame
+  playlist_box = (GtkWidget *)create_player_playlist_frame();
+  gtk_box_pack_start(GTK_BOX(player_vbox), playlist_box, TRUE, TRUE, 0);
+
+  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), 
+                           player_vbox,
+                           (GtkWidget *)notebook_label);
+      
   /* splitpoints page */
   notebook_label = gtk_label_new((gchar *)_("Splitpoints"));
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook), 
-			   splitpoints_vbox,
-			   (GtkWidget *)notebook_label);
+                           splitpoints_vbox,
+                           (GtkWidget *)notebook_label);
 
-  /* splitted files frame */
-  GtkWidget *splitted_files_vbox;
-  splitted_files_vbox = gtk_vbox_new (FALSE, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (splitted_files_vbox), 5);
+  /* split files frame */
+  GtkWidget *split_files_vbox;
+  split_files_vbox = gtk_vbox_new (FALSE, 0);
+  gtk_container_set_border_width (GTK_CONTAINER (split_files_vbox), 5);
   
-  frame = (GtkWidget *)create_splitted_files();
-  gtk_container_add(GTK_CONTAINER(splitted_files_vbox), frame);
+  frame = (GtkWidget *)create_split_files();
+  gtk_container_add(GTK_CONTAINER(split_files_vbox), frame);
   
-  notebook_label = gtk_label_new((gchar *)_("Splitted files"));
+  notebook_label = gtk_label_new((gchar *)_("Split files"));
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook), 
-			   splitted_files_vbox,
-			   (GtkWidget *)notebook_label);
+                           split_files_vbox,
+                           (GtkWidget *)notebook_label);
   
   /* cddb and cue page */
   GtkWidget *cddb_cue_vbox;
@@ -688,8 +731,8 @@ GtkWidget *create_main_vbox()
   
   notebook_label = gtk_label_new((gchar *)_("cddb&cue"));
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook), 
-			   cddb_cue_vbox,
-			   (GtkWidget *)notebook_label);
+                           cddb_cue_vbox,
+                           (GtkWidget *)notebook_label);
 
   /* freedb page */
   GtkWidget *freedb_vbox;
@@ -701,8 +744,8 @@ GtkWidget *create_main_vbox()
   
   notebook_label = gtk_label_new((gchar *)_("FreeDB"));
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook), 
-			   freedb_vbox,
-			   (GtkWidget *)notebook_label);
+                           freedb_vbox,
+                           (GtkWidget *)notebook_label);
   
   /* special split page */
   GtkWidget *special_split_vbox;
@@ -712,8 +755,8 @@ GtkWidget *create_main_vbox()
   gtk_container_add(GTK_CONTAINER(special_split_vbox), frame);
   notebook_label = gtk_label_new((gchar *)_("Split mode"));
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook), 
-			   special_split_vbox,
-			   (GtkWidget *)notebook_label);
+                           special_split_vbox,
+                           (GtkWidget *)notebook_label);
   
   /* preferences page */
   GtkWidget *preferences_vbox;
@@ -725,45 +768,45 @@ GtkWidget *create_main_vbox()
 
   notebook_label = gtk_label_new((gchar *)_("Preferences"));
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook), 
-			   preferences_vbox,
-			   (GtkWidget *)notebook_label);
+                           preferences_vbox,
+                           (GtkWidget *)notebook_label);
   
   /* progress bar */
   percent_progress_bar = gtk_progress_bar_new ();
   //we begin at 0
   gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(percent_progress_bar),
-				0.0);
+                                0.0);
   //we write 0 on the bar
   gtk_progress_bar_set_text(GTK_PROGRESS_BAR(percent_progress_bar),
-			    "");
+                            "");
   
   //hbox for progress bar and cancel button
   GtkWidget *hbox;
   hbox = gtk_hbox_new (FALSE,0);
   //we put the progress bar in the hbox
   gtk_box_pack_start(GTK_BOX(hbox),
-		     percent_progress_bar, TRUE, TRUE, 3);
+                     percent_progress_bar, TRUE, TRUE, 3);
   
   //stop button
   cancel_button = create_cool_button(GTK_STOCK_CANCEL,_("Stop"),
-				     FALSE);
+                                     FALSE);
   //action for the cancel button
   g_signal_connect(G_OBJECT(cancel_button), "clicked",
-		   G_CALLBACK(cancel_button_event), NULL);
+                   G_CALLBACK(cancel_button_event), NULL);
   
   //we put the stop button in the hbox
   gtk_box_pack_start(GTK_BOX(hbox),
-		     cancel_button, FALSE, TRUE, 3);
+                     cancel_button, FALSE, TRUE, 3);
   gtk_widget_set_sensitive(GTK_WIDGET(cancel_button), FALSE);
   
   //we put progress bar hbox in the main box
   gtk_box_pack_start(GTK_BOX (main_vbox),
-		     hbox, FALSE, FALSE, 3);  
+                     hbox, FALSE, FALSE, 3);  
   
   /* statusbar */
   status_bar = gtk_statusbar_new();
   gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(status_bar),
-				    TRUE);
+                                    TRUE);
   gtk_box_pack_start (GTK_BOX (main_vbox), status_bar, FALSE, FALSE, 0);
   
   return main_vbox;
@@ -798,231 +841,31 @@ void create_all()
   
   //hide the disconnect button
   gtk_widget_hide(disconnect_button);
-  
+
+  //hide the playlist window
+  gtk_widget_hide(playlist_box);
+
   //load preferences
   load_preferences();
   combo_remove_unavailable_players();
+
+  //hide connect button if player is gstreamer
+  if (selected_player == PLAYER_GSTREAMER)
+  {
+    gtk_widget_hide(connect_button);
+    gtk_widget_hide(toolbar_connect_button);
+  }
 }
 
 //print the status bar confirmation
 void print_status_bar_confirmation(gint confirmation)
 {
-  switch (confirmation) {
-  case MP3SPLT_SPLITPOINT_BIGGER_THAN_LENGTH :
-    put_status_message((gchar *)_(" file splitted, splitpoints bigger than length "));
-    break;
-  case MP3SPLT_OK_SPLITTED_OGG :
-    put_status_message((gchar *)_(" ogg splitted "));
-    break;
-  case MP3SPLT_OK_SPLITTED_MP3 :
-    put_status_message((gchar *)_(" mp3 splitted "));
-    break;
-  case MP3SPLT_OK_SPLITTED_OGG_EOF :
-    put_status_message((gchar *)_(" ogg splitted "));
-    break;
-  case MP3SPLT_OK_SPLITTED_MP3_EOF :
-    put_status_message((gchar *)_(" mp3 splitted "));
-    break;
-  case MP3SPLT_OK :
-    put_status_message((gchar *)_(" bug in the program, please report it "));
-    break;
-  case MP3SPLT_ERROR_SPLITPOINTS :
-    put_status_message((gchar *)_(" error: not enough splitpoints (<2) "));
-    break;
-  case MP3SPLT_ERROR_CANNOT_OPEN_FILE :
-    put_status_message((gchar *)_(" error: cannot open file "));
-    break;
-  case MP3SPLT_ERROR_INVALID_MP3 :
-    put_status_message((gchar *)_(" error: invalid mp3 file or libmp3splt "
-				  "compiled without ogg support"));
-    break;
-  case MP3SPLT_ERROR_INVALID_OGG :
-    put_status_message((gchar *)_(" error: invalid ogg file "));
-    break;
-  case MP3SPLT_ERROR_EQUAL_SPLITPOINTS :
-    put_status_message((gchar *)_(" error: equal splitpoints "));
-    break;
-  case MP3SPLT_ERROR_SPLITPOINTS_NOT_IN_ORDER :
-    put_status_message((gchar *)_(" error: splitpoints not in order "));
-    break;
-  case MP3SPLT_ERROR_NEGATIVE_SPLITPOINT :
-    put_status_message((gchar *)_(" error: negative splitpoint "));
-    break;
-  case MP3SPLT_ERROR_INCORRECT_PATH :
-    put_status_message((gchar *)_(" error: incorrect destination folder "));
-    break;
-  case MP3SPLT_FREEDB_OK :
-    put_status_message((gchar *)_(" freedb search processed ok "));
-    break;
-  case MP3SPLT_FREEDB_FILE_OK :
-    put_status_message((gchar *)_(" freedb file processed ok "));
-    break;
-  case MP3SPLT_FREEDB_CDDB_OK :
-    put_status_message((gchar *)_(" cddb file processed ok "));
-    break;
-  case MP3SPLT_FREEDB_CUE_OK :
-    put_status_message((gchar *)_(" cue file processed ok "));
-    break;
-  case MP3SPLT_FREEDB_ERROR_INITIALISE_SOCKET :
-    put_status_message((gchar *)_(" error: cannot initialise socket "));
-    break;
-  case MP3SPLT_FREEDB_ERROR_CANNOT_GET_HOST :
-    put_status_message((gchar *)_(" error: cannot get host by name "));
-    break;
-  case MP3SPLT_FREEDB_ERROR_CANNOT_OPEN_SOCKET :
-    put_status_message((gchar *)_(" error: cannot open socket "));
-    break;
-  case MP3SPLT_FREEDB_ERROR_CANNOT_CONNECT :
-    put_status_message((gchar *)_(" error: cannot connect to host "));
-    break;
-  case MP3SPLT_FREEDB_ERROR_CANNOT_SEND_MESSAGE :
-    put_status_message((gchar *)_(" error: cannot send message to host "));
-    break;
-  case MP3SPLT_FREEDB_ERROR_INVALID_SERVER_ANSWER :
-    put_status_message((gchar *)_(" error: invalid server answer "));
-    break;
-  case MP3SPLT_FREEDB_ERROR_SITE_201 :
-    put_status_message((gchar *)_(" error: error 201 while connecting"
-				  " to site "));
-    break;
-  case MP3SPLT_FREEDB_ERROR_SITE_200 :
-    put_status_message((gchar *)_(" error: error 200 while connecting"
-				  " to site "));
-    break;
-  case MP3SPLT_FREEDB_ERROR_BAD_COMMUNICATION :
-    put_status_message((gchar *)_(" error: bad communication with site "));
-    break;
-  case MP3SPLT_FREEDB_ERROR_GETTING_INFOS :
-    put_status_message((gchar *)_(" error: could not get infos from site "));
-    break;
-  case MP3SPLT_FREEDB_NO_CD_FOUND :
-    put_status_message((gchar *)_(" no cd found for this search "));
-    break;
-  case MP3SPLT_FREEDB_MAX_CD_REACHED :
-    put_status_message((gchar *)_(" maximum number of found"
-				  " CD reached "));
-    break;
-  case MP3SPLT_CUE_ERROR_CANNOT_OPEN_FILE_READING:
-    put_status_message((gchar *)_(" cue error: cannot read "
-				  "file"));
-    break;
-  case MP3SPLT_CDDB_ERROR_CANNOT_OPEN_FILE_READING:
-    put_status_message((gchar *)_(" cddb error: cannot read "
-				  "file"));
-    break;
-  case MP3SPLT_INVALID_CUE_FILE:
-    put_status_message((gchar *)_(" cue error: invalid "
-				  "cue file"));
-    break;
-  case MP3SPLT_INVALID_CDDB_FILE:
-    put_status_message((gchar *)_(" cddb error: invalid "
-				  "cddb file"));
-    break;
-  case MP3SPLT_SILENCE_OK:
-    put_status_message((gchar *)_(" silence split ok "));
-    break;
-  case MP3SPLT_ERROR_CANNOT_SYNC_OGG:
-    put_status_message((gchar *)_(" sync error: cannot sync ogg files "));
-    break;
-  case MP3SPLT_ERROR_INCOMPATIBLE_OPTIONS:
-    put_status_message((gchar *)_(" error: incompatible options "));
-    break;
-  case MP3SPLT_ERROR_SILENCE:
-    put_status_message((gchar *)_(" error for the silence split "));
-    break;
-  case MP3SPLT_MP3_SYNC_OK:
-    put_status_message((gchar *)_(" mp3 error mode ok "));
-    break;
-  case MP3SPLT_MP3_ERR_SYNC:
-    put_status_message((gchar *)_(" error: mp3 sync "));
-    break;
-  case MP3SPLT_MP3_ERR_NO_SYNC_FOUND:
-    put_status_message((gchar *)_(" no sync errors found "));
-    break;
-  case MP3SPLT_MP3_ERR_TOO_MANY_SYNC_ERR:
-    put_status_message((gchar *)_(" sync error: too many sync errors "));
-    break;
-  case MP3SPLT_DEWRAP_OK:
-    put_status_message((gchar *)_(" wrap split ok "));
-    break;
-  case MP3SPLT_DEWRAP_ERR_FILE_LENGTH:
-    put_status_message((gchar *)_(" wrap error: file length "));
-    break;
-  case MP3SPLT_DEWRAP_ERR_VERSION_OLD:
-    put_status_message((gchar *)_(" wrap error: version too old "));
-    break;
-  case MP3SPLT_DEWRAP_ERR_NO_FILE_OR_BAD_INDEX:
-    put_status_message((gchar *)_(" wrap error: no file or bad "
-				  "index"));
-    break;
-  case MP3SPLT_DEWRAP_ERR_FILE_DAMAGED_INCOMPLETE:
-    put_status_message((gchar *)_(" wrap error: file damaged or "
-				  "incomplete"));
-    break;
-  case MP3SPLT_DEWRAP_ERR_FILE_NOT_WRAPED_DAMAGED:
-    put_status_message((gchar *)_(" wrap error: maybe not a wrapped"
-				  " file or wrap file damaged")); 
-    break;
-  case MP3SPLT_TIME_SPLIT_OK:
-    put_status_message((gchar *)_(" time split ok ")); 
-    break;
-  case MP3SPLT_ERROR_INPUT_OUTPUT_SAME_FILE:
-    put_status_message((gchar *)_(" error: input and output are the same file ")); 
-    break;
-  case MP3SPLT_ERROR_TIME:
-    put_status_message((gchar *)_(" unknown error on time split ")); 
-    break;
-  case MP3SPLT_NO_SILENCE_SPLITPOINTS_FOUND:
-    put_status_message((gchar *)_(" no silence splitpoints found "));
-    break;
-  case MP3SPLT_ERROR_CANNOT_ALLOCATE_MEMORY:
-    put_status_message((gchar *)_(" error: unable to allocate"
-				  " memory "));
-    break;
-  case MP3SPLT_MP3_MIGHT_BE_VBR:
-    put_status_message((gchar *)_(" warning: mp3 might be VBR,"
-				  " use frame mode "));
-    break;
-  case MP3SPLT_ERROR_CANNOT_OPEN_DEST_FILE:
-    put_status_message((gchar *)_(" error: cannot open"
-				  " destination file "));
-    break;
-  case MP3SPLT_ERROR_CANT_WRITE_TO_OUTPUT_FILE:
-    put_status_message((gchar *)_(" error: cannot write"
-				  " to output file "));
-    break;
-  case MP3SPLT_ERROR_WHILE_READING_FILE:
-    put_status_message((gchar *)_(" error: cannot read"
-				  " file "));
-    break;
-  case MP3SPLT_ERROR_SEEKING_FILE:
-    put_status_message((gchar *)_(" error: cannot seek"
-				  " file "));
-    break;
-  case MP3SPLT_ERROR_BEGIN_OUT_OF_FILE:
-    put_status_message((gchar *)_(" error: begin point out"
-				  " of file "));
-    break;
-  case MP3SPLT_ERROR_INEXISTENT_FILE:
-    put_status_message((gchar *)_(" error: inexistent file "));
-    break;
-  case MP3SPLT_SPLIT_CANCELLED:
-    put_status_message((gchar *)_(" split process cancelled "));
-    break;
-  case MP3SPLT_ERROR_OGG_WRAP_NOT_IMPLEMENTED:
-    put_status_message((gchar *)_(" wrap error: ogg wrap not implemented "));
-    break;
-  case MP3SPLT_OUTPUT_FORMAT_OK:
-    remove_status_message();
-    break;
-  case MP3SPLT_OUTPUT_FORMAT_ERROR:
-    put_status_message((gchar *)_(" warning: output format error "));
-    break;
-  case MP3SPLT_OUTPUT_FORMAT_AMBIGUOUS:
-    put_status_message((gchar *)_(" warning: output format ambiguous"));
-    break;
-  default:
-    break;
-  }  
+  char *error_from_library = mp3splt_get_strerror(the_state, confirmation);
+  if (error_from_library != NULL)
+  {
+    put_status_message(error_from_library);
+    free(error_from_library);
+    error_from_library = NULL;
+  }
 }
 
